"""
Generated class for SubscriptionTopic. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class QueryCriteria(FhirBaseModel):
    """The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str previous: Rule applied to previous resource state
    :param str resultForCreate: test-passes | test-fails
    :param str current: Rule applied to current resource state
    :param str resultForDelete: test-passes | test-fails
    :param bool requireBoth: Both must be true flag
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        previous: "str" = None,
        resultForCreate: "str" = None,
        current: "str" = None,
        resultForDelete: "str" = None,
        requireBoth: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.previous = previous
        self.resultForCreate = resultForCreate
        self.current = current
        self.resultForDelete = resultForDelete
        self.requireBoth = requireBoth

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ResourceTrigger(FhirBaseModel):
    """A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Text representation of the resource trigger
    :param str resource: Data Type or Resource (reference to definition) for this trigger definition
    :param str supportedInteraction: create | update | delete
    :param QueryCriteria queryCriteria: Query based trigger rule
    :param str fhirPathCriteria: FHIRPath based trigger rule
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "queryCriteria": {"class_name": "QueryCriteria", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        resource: "str" = None,
        supportedInteraction: list["str"] = None,
        queryCriteria: "QueryCriteria" = None,
        fhirPathCriteria: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.resource = resource
        self.supportedInteraction = supportedInteraction or []
        self.queryCriteria = queryCriteria
        self.fhirPathCriteria = fhirPathCriteria

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EventTrigger(FhirBaseModel):
    """Event definition which can be used to trigger the SubscriptionTopic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Text representation of the event trigger
    :param CodeableConcept event: Event which can trigger a notification from the SubscriptionTopic
    :param str resource: Data Type or Resource (reference to definition) for this trigger definition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "event": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        event: "CodeableConcept" = None,
        resource: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.event = event
        self.resource = resource

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CanFilterBy(FhirBaseModel):
    """List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of this filter parameter
    :param str resource: URL of the triggering Resource that this filter applies to
    :param str filterParameter: Human-readable and computation-friendly name for a filter parameter usable by subscriptions on this topic, via Subscription.filterBy.filterParameter
    :param str filterDefinition: Canonical URL for a filterParameter definition
    :param str modifier: = | eq | ne | gt | lt | ge | le | sa | eb | ap | above | below | in | not-in | of-type
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        resource: "str" = None,
        filterParameter: "str" = None,
        filterDefinition: "str" = None,
        modifier: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.resource = resource
        self.filterParameter = filterParameter
        self.filterDefinition = filterDefinition
        self.modifier = modifier or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class NotificationShape(FhirBaseModel):
    """List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str resource: URL of the Resource that is the focus (main) resource in a notification shape
    :param str include: Include directives, rooted in the resource for this shape
    :param str revInclude: Reverse include directives, rooted in the resource for this shape
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        resource: "str" = None,
        include: list["str"] = None,
        revInclude: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.resource = resource
        self.include = include or []
        self.revInclude = revInclude or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubscriptionTopic(DomainResource):
    """Describes a stream of resource state changes identified by trigger criteria and annotated with labels useful to filter projections from this topic.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this subscription topic definition, represented as a URI (globally unique)
    :param Identifier identifier: Business Identifier for this subscription topic
    :param str version: Business version of the subscription topic
    :param str title: Name for this subscription topic (Human friendly)
    :param str derivedFrom: Based on FHIR protocol or definition
    :param str status: draft | active | retired | unknown
    :param bool experimental: If for testing purposes, not real usage
    :param str date: Date status first applied
    :param str publisher: The name of the individual or organization that published the SubscriptionTopic
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the SubscriptionTopic
    :param UsageContext useContext: Content intends to support these contexts
    :param CodeableConcept jurisdiction: Intended jurisdiction of the SubscriptionTopic (if applicable)
    :param str purpose: Why this SubscriptionTopic is defined
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When SubscriptionTopic is/was approved by publisher
    :param str lastReviewDate: Date the Subscription Topic was last reviewed by the publisher
    :param Period effectivePeriod: The effective date range for the SubscriptionTopic
    :param ResourceTrigger resourceTrigger: Definition of a resource-based trigger for the subscription topic
    :param EventTrigger eventTrigger: Event definitions the SubscriptionTopic
    :param CanFilterBy canFilterBy: Properties by which a Subscription can filter notifications from the SubscriptionTopic
    :param NotificationShape notificationShape: Properties for describing the shape of notifications generated by this topic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "resourceTrigger": {"class_name": "ResourceTrigger", "is_contained": True},
        "eventTrigger": {"class_name": "EventTrigger", "is_contained": True},
        "canFilterBy": {"class_name": "CanFilterBy", "is_contained": True},
        "notificationShape": {"class_name": "NotificationShape", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        title: "str" = None,
        derivedFrom: list["str"] = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        resourceTrigger: list["ResourceTrigger"] = None,
        eventTrigger: list["EventTrigger"] = None,
        canFilterBy: list["CanFilterBy"] = None,
        notificationShape: list["NotificationShape"] = None,
    ):

        self.resourceType = "SubscriptionTopic"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.title = title
        self.derivedFrom = derivedFrom or []
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.resourceTrigger = resourceTrigger or []
        self.eventTrigger = eventTrigger or []
        self.canFilterBy = canFilterBy or []
        self.notificationShape = notificationShape or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubscriptionTopic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubscriptionTopic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DeviceMetric. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *


class Calibration(FhirBaseModel):
    """Describes the calibrations that have been performed or that are required to be performed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: unspecified | offset | gain | two-point
    :param str state: not-calibrated | calibration-required | calibrated | unspecified
    :param str time: Describes the time last calibration has been performed
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        state: "str" = None,
        time: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.state = state
        self.time = time

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceMetric":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceMetric":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DeviceMetric(DomainResource):
    """Describes a measurement, calculation or setting capability of a medical device.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Instance identifier
    :param CodeableConcept type: Identity of metric, for example Heart Rate or PEEP Setting
    :param CodeableConcept unit: Unit of Measure for the Metric
    :param Reference source: Describes the link to the source Device
    :param Reference parent: Describes the link to the parent Device
    :param str operationalStatus: on | off | standby | entered-in-error
    :param str color: black | red | green | yellow | blue | magenta | cyan | white
    :param str category: measurement | setting | calculation | unspecified
    :param Timing measurementPeriod: Describes the measurement repetition time
    :param Calibration calibration: Describes the calibrations that have been performed or that are required to be performed
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "unit": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
        "parent": {"class_name": "Reference", "is_contained": False},
        "measurementPeriod": {"class_name": "Timing", "is_contained": False},
        "calibration": {"class_name": "Calibration", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        unit: "CodeableConcept" = None,
        source: "Reference" = None,
        parent: "Reference" = None,
        operationalStatus: "str" = None,
        color: "str" = None,
        category: "str" = None,
        measurementPeriod: "Timing" = None,
        calibration: list["Calibration"] = None,
    ):

        self.resourceType = "DeviceMetric"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.unit = unit
        self.source = source
        self.parent = parent
        self.operationalStatus = operationalStatus
        self.color = color
        self.category = category
        self.measurementPeriod = measurementPeriod
        self.calibration = calibration or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceMetric":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceMetric":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for InventoryReport. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Item(FhirBaseModel):
    """The item or items in this listing.:param CodeableConcept itemStatus: The status of the items that are being reported
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: The inventory category or classification of the items being reported
    :param Quantity quantity: The quantity of the item or items being reported
    :param CodeableReference item: The code or reference to the item type
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "itemStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        itemStatus: "CodeableConcept" = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        item: "CodeableReference" = None,
    ):
        self.itemStatus = itemStatus
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.quantity = quantity
        self.item = item

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class InventoryListing(FhirBaseModel):
    """An inventory listing section (grouped by any of the attributes).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference location: Location of the inventory items
    :param CodeableConcept itemStatus: The status of the items that are being reported
    :param str countingDateTime: The date and time when the items were counted
    :param Item item: The item or items in this listing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "itemStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "item": {"class_name": "Item", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        location: "Reference" = None,
        itemStatus: "CodeableConcept" = None,
        countingDateTime: "str" = None,
        item: list["Item"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.location = location
        self.itemStatus = itemStatus
        self.countingDateTime = countingDateTime
        self.item = item or []

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class InventoryReport(DomainResource):
    """A report of inventory or stock items.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for the report
    :param str status: draft | requested | active | entered-in-error
    :param str countType: snapshot | difference
    :param CodeableConcept operationType: addition | subtraction
    :param CodeableConcept operationTypeReason: The reason for this count - regular count, ad-hoc count, new arrivals, etc
    :param str reportedDateTime: When the report has been submitted
    :param Reference reporter: Who submits the report
    :param Period reportingPeriod: The period the report refers to
    :param InventoryListing inventoryListing: An inventory listing section (grouped by any of the attributes)
    :param Annotation note: A note associated with the InventoryReport
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "operationType": {"class_name": "CodeableConcept", "is_contained": False},
        "operationTypeReason": {"class_name": "CodeableConcept", "is_contained": False},
        "reporter": {"class_name": "Reference", "is_contained": False},
        "reportingPeriod": {"class_name": "Period", "is_contained": False},
        "inventoryListing": {"class_name": "InventoryListing", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        countType: "str" = None,
        operationType: "CodeableConcept" = None,
        operationTypeReason: "CodeableConcept" = None,
        reportedDateTime: "str" = None,
        reporter: "Reference" = None,
        reportingPeriod: "Period" = None,
        inventoryListing: list["InventoryListing"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "InventoryReport"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.countType = countType
        self.operationType = operationType
        self.operationTypeReason = operationTypeReason
        self.reportedDateTime = reportedDateTime
        self.reporter = reporter
        self.reportingPeriod = reportingPeriod
        self.inventoryListing = inventoryListing or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Measure. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Expression import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.RelatedArtifact import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Population(FhirBaseModel):
    """A population criteria for the measure.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: initial-population | numerator | numerator-exclusion | denominator | denominator-exclusion | denominator-exception | measure-population | measure-population-exclusion | measure-observation
    :param str description: The human readable description of this population criteria
    :param Expression criteria: The criteria that defines this population
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "criteria": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        criteria: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.description = description
        self.criteria = criteria

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Component(FhirBaseModel):
    """A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Meaning of the stratifier component
    :param str description: The human readable description of this stratifier component
    :param Expression criteria: Component of how the measure should be stratified
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "criteria": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        criteria: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.description = description
        self.criteria = criteria

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Stratifier(FhirBaseModel):
    """The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Meaning of the stratifier
    :param str description: The human readable description of this stratifier
    :param Expression criteria: How the measure should be stratified
    :param Component component: Stratifier criteria component for the measure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "criteria": {"class_name": "Expression", "is_contained": False},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        criteria: "Expression" = None,
        component: list["Component"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.description = description
        self.criteria = criteria
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Group(FhirBaseModel):
    """A group of population criteria for the measure.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Meaning of the group
    :param str description: Summary description
    :param Population population: Population criteria
    :param Stratifier stratifier: Stratifier criteria for the measure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "population": {"class_name": "Population", "is_contained": True},
        "stratifier": {"class_name": "Stratifier", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        population: list["Population"] = None,
        stratifier: list["Stratifier"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.description = description
        self.population = population or []
        self.stratifier = stratifier or []

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SupplementalData(FhirBaseModel):
    """The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Meaning of the supplemental data
    :param CodeableConcept usage: supplemental-data | risk-adjustment-factor
    :param str description: The human readable description of this supplemental data
    :param Expression criteria: Expression describing additional data to be reported
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "usage": {"class_name": "CodeableConcept", "is_contained": False},
        "criteria": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        usage: list["CodeableConcept"] = None,
        description: "str" = None,
        criteria: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.usage = usage or []
        self.description = description
        self.criteria = criteria

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Measure(DomainResource):
    """The Measure resource provides the definition of a quality measure.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this measure, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the measure
    :param str version: Business version of the measure
    :param str name: Name for this measure (computer friendly)
    :param str title: Name for this measure (human friendly)
    :param str subtitle: Subordinate title of the measure
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param CodeableConcept subjectCodeableConcept: E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device
    :param Reference subjectReference: E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the measure
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for measure (if applicable)
    :param str purpose: Why this measure is defined
    :param str usage: Describes the clinical usage of the measure
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When the measure was approved by publisher
    :param str lastReviewDate: When the measure was last reviewed
    :param Period effectivePeriod: When the measure is expected to be used
    :param CodeableConcept topic: The category of the measure, such as Education, Treatment, Assessment, etc.
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param RelatedArtifact relatedArtifact: Additional documentation, citations, etc.
    :param str library: Logic used by the measure
    :param str disclaimer: Disclaimer for use of the measure or its referenced content
    :param CodeableConcept scoring: proportion | ratio | continuous-variable | cohort
    :param CodeableConcept compositeScoring: opportunity | all-or-nothing | linear | weighted
    :param CodeableConcept type: process | outcome | structure | patient-reported-outcome | composite
    :param str riskAdjustment: How risk adjustment is applied for this measure
    :param str rateAggregation: How is rate aggregation performed for this measure
    :param str rationale: Detailed description of why the measure exists
    :param str clinicalRecommendationStatement: Summary of clinical guidelines
    :param CodeableConcept improvementNotation: increase | decrease
    :param str definition: Defined terms used in the measure documentation
    :param str guidance: Additional guidance for implementers
    :param Group group: Population criteria group
    :param SupplementalData supplementalData: What other data should be reported with the measure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subjectCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "subjectReference": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "scoring": {"class_name": "CodeableConcept", "is_contained": False},
        "compositeScoring": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "improvementNotation": {"class_name": "CodeableConcept", "is_contained": False},
        "group": {"class_name": "Group", "is_contained": True},
        "supplementalData": {"class_name": "SupplementalData", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        subtitle: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        subjectCodeableConcept: "CodeableConcept" = None,
        subjectReference: "Reference" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        usage: "str" = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        library: list["str"] = None,
        disclaimer: "str" = None,
        scoring: "CodeableConcept" = None,
        compositeScoring: "CodeableConcept" = None,
        type: list["CodeableConcept"] = None,
        riskAdjustment: "str" = None,
        rateAggregation: "str" = None,
        rationale: "str" = None,
        clinicalRecommendationStatement: "str" = None,
        improvementNotation: "CodeableConcept" = None,
        definition: list["str"] = None,
        guidance: "str" = None,
        group: list["Group"] = None,
        supplementalData: list["SupplementalData"] = None,
    ):

        self.resourceType = "Measure"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.subtitle = subtitle
        self.status = status
        self.experimental = experimental
        self.subjectCodeableConcept = subjectCodeableConcept
        self.subjectReference = subjectReference
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.usage = usage
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatedArtifact = relatedArtifact or []
        self.library = library or []
        self.disclaimer = disclaimer
        self.scoring = scoring
        self.compositeScoring = compositeScoring
        self.type = type or []
        self.riskAdjustment = riskAdjustment
        self.rateAggregation = rateAggregation
        self.rationale = rationale
        self.clinicalRecommendationStatement = clinicalRecommendationStatement
        self.improvementNotation = improvementNotation
        self.definition = definition or []
        self.guidance = guidance
        self.group = group or []
        self.supplementalData = supplementalData or []

    @classmethod
    def from_dict(cls, data: dict) -> "Measure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Measure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationRequest. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Dosage import *
from fhirmodels.R4.Duration import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class InitialFill(FhirBaseModel):
    """Indicates the quantity or duration for the first dispense of the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: First fill quantity
    :param Duration duration: First fill duration
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "duration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        duration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.duration = duration

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DispenseRequest(FhirBaseModel):
    """Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param InitialFill initialFill: First fill details
    :param Duration dispenseInterval: Minimum period of time between dispenses
    :param Period validityPeriod: Time period supply is authorized for
    :param int numberOfRepeatsAllowed: Number of refills authorized
    :param Quantity quantity: Amount of medication to supply per dispense
    :param Duration expectedSupplyDuration: Number of days supply per dispense
    :param Reference performer: Intended dispenser
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "initialFill": {"class_name": "InitialFill", "is_contained": True},
        "dispenseInterval": {"class_name": "Duration", "is_contained": False},
        "validityPeriod": {"class_name": "Period", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "expectedSupplyDuration": {"class_name": "Duration", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        initialFill: "InitialFill" = None,
        dispenseInterval: "Duration" = None,
        validityPeriod: "Period" = None,
        numberOfRepeatsAllowed: "int" = None,
        quantity: "Quantity" = None,
        expectedSupplyDuration: "Duration" = None,
        performer: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.initialFill = initialFill
        self.dispenseInterval = dispenseInterval
        self.validityPeriod = validityPeriod
        self.numberOfRepeatsAllowed = numberOfRepeatsAllowed
        self.quantity = quantity
        self.expectedSupplyDuration = expectedSupplyDuration
        self.performer = performer

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substitution(FhirBaseModel):
    """Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool allowedBoolean: Whether substitution is allowed or not
    :param CodeableConcept allowedCodeableConcept: Whether substitution is allowed or not
    :param CodeableConcept reason: Why should (not) substitution be made
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "allowedCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        allowedBoolean: "bool" = None,
        allowedCodeableConcept: "CodeableConcept" = None,
        reason: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.allowedBoolean = allowedBoolean
        self.allowedCodeableConcept = allowedCodeableConcept
        self.reason = reason

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationRequest(DomainResource):
    """An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External ids for this request
    :param str status: active | on-hold | cancelled | completed | entered-in-error | stopped | draft | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param str intent: proposal | plan | order | original-order | reflex-order | filler-order | instance-order | option
    :param CodeableConcept category: Type of medication usage
    :param str priority: routine | urgent | asap | stat
    :param bool doNotPerform: True if request is prohibiting action
    :param bool reportedBoolean: Reported rather than primary record
    :param Reference reportedReference: Reported rather than primary record
    :param CodeableConcept medicationCodeableConcept: Medication to be taken
    :param Reference medicationReference: Medication to be taken
    :param Reference subject: Who or group medication request is for
    :param Reference encounter: Encounter created as part of encounter/admission/stay
    :param Reference supportingInformation: Information to support ordering of the medication
    :param str authoredOn: When request was initially authored
    :param Reference requester: Who/What requested the Request
    :param Reference performer: Intended performer of administration
    :param CodeableConcept performerType: Desired kind of performer of the medication administration
    :param Reference recorder: Person who entered the request
    :param CodeableConcept reasonCode: Reason or indication for ordering or not ordering the medication
    :param Reference reasonReference: Condition or observation that supports why the prescription is being written
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: What request fulfills
    :param Identifier groupIdentifier: Composite request this is part of
    :param CodeableConcept courseOfTherapyType: Overall pattern of medication administration
    :param Reference insurance: Associated insurance coverage
    :param Annotation note: Information about the prescription
    :param Dosage dosageInstruction: How the medication should be taken
    :param DispenseRequest dispenseRequest: Medication supply authorization
    :param Substitution substitution: Any restrictions on medication substitution
    :param Reference priorPrescription: An order/prescription that is being replaced
    :param Reference detectedIssue: Clinical Issue with action
    :param Reference eventHistory: A list of events of interest in the lifecycle
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "reportedReference": {"class_name": "Reference", "is_contained": False},
        "medicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationReference": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "recorder": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "groupIdentifier": {"class_name": "Identifier", "is_contained": False},
        "courseOfTherapyType": {"class_name": "CodeableConcept", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "dosageInstruction": {"class_name": "Dosage", "is_contained": False},
        "dispenseRequest": {"class_name": "DispenseRequest", "is_contained": True},
        "substitution": {"class_name": "Substitution", "is_contained": True},
        "priorPrescription": {"class_name": "Reference", "is_contained": False},
        "detectedIssue": {"class_name": "Reference", "is_contained": False},
        "eventHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        intent: "str" = None,
        category: list["CodeableConcept"] = None,
        priority: "str" = None,
        doNotPerform: "bool" = None,
        reportedBoolean: "bool" = None,
        reportedReference: "Reference" = None,
        medicationCodeableConcept: "CodeableConcept" = None,
        medicationReference: "Reference" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        supportingInformation: list["Reference"] = None,
        authoredOn: "str" = None,
        requester: "Reference" = None,
        performer: "Reference" = None,
        performerType: "CodeableConcept" = None,
        recorder: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        groupIdentifier: "Identifier" = None,
        courseOfTherapyType: "CodeableConcept" = None,
        insurance: list["Reference"] = None,
        note: list["Annotation"] = None,
        dosageInstruction: list["Dosage"] = None,
        dispenseRequest: "DispenseRequest" = None,
        substitution: "Substitution" = None,
        priorPrescription: "Reference" = None,
        detectedIssue: list["Reference"] = None,
        eventHistory: list["Reference"] = None,
    ):

        self.resourceType = "MedicationRequest"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.statusReason = statusReason
        self.intent = intent
        self.category = category or []
        self.priority = priority
        self.doNotPerform = doNotPerform
        self.reportedBoolean = reportedBoolean
        self.reportedReference = reportedReference
        self.medicationCodeableConcept = medicationCodeableConcept
        self.medicationReference = medicationReference
        self.subject = subject
        self.encounter = encounter
        self.supportingInformation = supportingInformation or []
        self.authoredOn = authoredOn
        self.requester = requester
        self.performer = performer
        self.performerType = performerType
        self.recorder = recorder
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.groupIdentifier = groupIdentifier
        self.courseOfTherapyType = courseOfTherapyType
        self.insurance = insurance or []
        self.note = note or []
        self.dosageInstruction = dosageInstruction or []
        self.dispenseRequest = dispenseRequest
        self.substitution = substitution
        self.priorPrescription = priorPrescription
        self.detectedIssue = detectedIssue or []
        self.eventHistory = eventHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for BodyStructure. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class DistanceFromLandmark(FhirBaseModel):
    """The distance in centimeters a certain observation is made from a body landmark.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference device: Measurement device
    :param Quantity value: Measured distance from body landmark
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "device": {"class_name": "CodeableReference", "is_contained": False},
        "value": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        device: list["CodeableReference"] = None,
        value: list["Quantity"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.device = device or []
        self.value = value or []

    @classmethod
    def from_dict(cls, data: dict) -> "BodyStructure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BodyStructure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class BodyLandmarkOrientation(FhirBaseModel):
    """Body locations in relation to a specific body landmark (tatoo, scar, other body structure).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept landmarkDescription: Body ]andmark description
    :param CodeableConcept clockFacePosition: Clockface orientation
    :param DistanceFromLandmark distanceFromLandmark: Landmark relative location
    :param CodeableConcept surfaceOrientation: Relative landmark surface orientation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "landmarkDescription": {"class_name": "CodeableConcept", "is_contained": False},
        "clockFacePosition": {"class_name": "CodeableConcept", "is_contained": False},
        "distanceFromLandmark": {
            "class_name": "DistanceFromLandmark",
            "is_contained": True,
        },
        "surfaceOrientation": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        landmarkDescription: list["CodeableConcept"] = None,
        clockFacePosition: list["CodeableConcept"] = None,
        distanceFromLandmark: list["DistanceFromLandmark"] = None,
        surfaceOrientation: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.landmarkDescription = landmarkDescription or []
        self.clockFacePosition = clockFacePosition or []
        self.distanceFromLandmark = distanceFromLandmark or []
        self.surfaceOrientation = surfaceOrientation or []

    @classmethod
    def from_dict(cls, data: dict) -> "BodyStructure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BodyStructure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class IncludedStructure(FhirBaseModel):
    """The anatomical location(s) or region(s) of the specimen, lesion, or body structure.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept structure: Code that represents the included structure
    :param CodeableConcept laterality: Code that represents the included structure laterality
    :param BodyLandmarkOrientation bodyLandmarkOrientation: Landmark relative location
    :param Reference spatialReference: Cartesian reference for structure
    :param CodeableConcept qualifier: Code that represents the included structure qualifier
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "structure": {"class_name": "CodeableConcept", "is_contained": False},
        "laterality": {"class_name": "CodeableConcept", "is_contained": False},
        "bodyLandmarkOrientation": {
            "class_name": "BodyLandmarkOrientation",
            "is_contained": True,
        },
        "spatialReference": {"class_name": "Reference", "is_contained": False},
        "qualifier": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        structure: "CodeableConcept" = None,
        laterality: "CodeableConcept" = None,
        bodyLandmarkOrientation: list["BodyLandmarkOrientation"] = None,
        spatialReference: list["Reference"] = None,
        qualifier: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.structure = structure
        self.laterality = laterality
        self.bodyLandmarkOrientation = bodyLandmarkOrientation or []
        self.spatialReference = spatialReference or []
        self.qualifier = qualifier or []

    @classmethod
    def from_dict(cls, data: dict) -> "BodyStructure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BodyStructure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class BodyStructure(DomainResource):
    """Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Bodystructure identifier
    :param bool active: Whether this record is in active use
    :param CodeableConcept morphology: Kind of Structure
    :param IncludedStructure includedStructure: Included anatomic location(s)
    :param ExcludedStructure excludedStructure: Excluded anatomic locations(s)
    :param str description: Text description
    :param Attachment image: Attached images
    :param Reference patient: Who this is about
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "morphology": {"class_name": "CodeableConcept", "is_contained": False},
        "includedStructure": {"class_name": "IncludedStructure", "is_contained": True},
        "excludedStructure": {"class_name": "ExcludedStructure", "is_contained": True},
        "image": {"class_name": "Attachment", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        morphology: "CodeableConcept" = None,
        includedStructure: list["IncludedStructure"] = None,
        excludedStructure: list["ExcludedStructure"] = None,
        description: "str" = None,
        image: list["Attachment"] = None,
        patient: "Reference" = None,
    ):

        self.resourceType = "BodyStructure"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.morphology = morphology
        self.includedStructure = includedStructure or []
        self.excludedStructure = excludedStructure or []
        self.description = description
        self.image = image or []
        self.patient = patient

    @classmethod
    def from_dict(cls, data: dict) -> "BodyStructure":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BodyStructure":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ResearchStudy. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *


class Label(FhirBaseModel):
    """Additional names for the study.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: primary | official | scientific | plain-language | subtitle | short-title | acronym | earlier-title | language | auto-translated | human-use | machine-use | duplicate-uid
    :param str value: The name
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AssociatedParty(FhirBaseModel):
    """Sponsors, collaborators, and other parties.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name of associated party
    :param CodeableConcept role: sponsor | lead-sponsor | sponsor-investigator | primary-investigator | collaborator | funding-source | general-contact | recruitment-contact | sub-investigator | study-director | study-chair
    :param Period period: When active in the role
    :param CodeableConcept classifier: nih | fda | government | nonprofit | academic | industry
    :param Reference party: Individual or organization associated with study (use practitionerRole to specify their organisation)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        role: "CodeableConcept" = None,
        period: list["Period"] = None,
        classifier: list["CodeableConcept"] = None,
        party: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.role = role
        self.period = period or []
        self.classifier = classifier or []
        self.party = party

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProgressStatus(FhirBaseModel):
    """Status of study with time for that status.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept state: Label for status or state (e.g. recruitment status)
    :param bool actual: Actual if true else anticipated
    :param Period period: Date range
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "state": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        state: "CodeableConcept" = None,
        actual: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.state = state
        self.actual = actual
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Recruitment(FhirBaseModel):
    """Target or actual group of participants enrolled in study.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int targetNumber: Estimated total number of participants to be enrolled
    :param int actualNumber: Actual total number of participants enrolled in study
    :param Reference eligibility: Inclusion and exclusion criteria
    :param Reference actualGroup: Group of participants who were enrolled in study
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "eligibility": {"class_name": "Reference", "is_contained": False},
        "actualGroup": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        targetNumber: "int" = None,
        actualNumber: "int" = None,
        eligibility: "Reference" = None,
        actualGroup: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.targetNumber = targetNumber
        self.actualNumber = actualNumber
        self.eligibility = eligibility
        self.actualGroup = actualGroup

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ComparisonGroup(FhirBaseModel):
    """Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str linkId: Allows the comparisonGroup for the study and the comparisonGroup for the subject to be linked easily
    :param str name: Label for study comparisonGroup
    :param CodeableConcept type: Categorization of study comparisonGroup
    :param str description: Short explanation of study path
    :param Reference intendedExposure: Interventions or exposures in this comparisonGroup or cohort
    :param Reference observedGroup: Group of participants who were enrolled in study comparisonGroup
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "intendedExposure": {"class_name": "Reference", "is_contained": False},
        "observedGroup": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        linkId: "str" = None,
        name: "str" = None,
        type: "CodeableConcept" = None,
        description: "str" = None,
        intendedExposure: list["Reference"] = None,
        observedGroup: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.linkId = linkId
        self.name = name
        self.type = type
        self.description = description
        self.intendedExposure = intendedExposure or []
        self.observedGroup = observedGroup

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Objective(FhirBaseModel):
    """A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Label for the objective
    :param CodeableConcept type: primary | secondary | exploratory
    :param str description: Description of the objective
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        type: "CodeableConcept" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.type = type
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class OutcomeMeasure(FhirBaseModel):
    """An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Label for the outcome
    :param CodeableConcept type: primary | secondary | exploratory
    :param str description: Description of the outcome
    :param Reference reference: Structured outcome definition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        type: list["CodeableConcept"] = None,
        description: "str" = None,
        reference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.type = type or []
        self.description = description
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ResearchStudy(DomainResource):
    """A scientific study of nature that sometimes includes processes involved in health and disease. For example, clinical trials are research studies that involve people. These studies may be related to new ways to screen, prevent, diagnose, and treat disease. They may also study certain outcomes and certain groups of people by looking at data collected in the past or future.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this study resource
    :param Identifier identifier: Business Identifier for study
    :param str version: The business version for the study record
    :param str name: Name for this study (computer friendly)
    :param str title: Human readable name of the study
    :param Label label: Additional names for the study
    :param Reference protocol: Steps followed in executing study
    :param Reference partOf: Part of larger study
    :param RelatedArtifact relatedArtifact: References, URLs, and attachments
    :param str date: Date the resource last changed
    :param str status: draft | active | retired | unknown
    :param CodeableConcept primaryPurposeType: treatment | prevention | diagnostic | supportive-care | screening | health-services-research | basic-science | device-feasibility
    :param CodeableConcept phase: n-a | early-phase-1 | phase-1 | phase-1-phase-2 | phase-2 | phase-2-phase-3 | phase-3 | phase-4
    :param CodeableConcept studyDesign: Classifications of the study design characteristics
    :param CodeableReference focus: Drugs, devices, etc. under study
    :param CodeableConcept condition: Condition being studied
    :param CodeableConcept keyword: Used to search for the study
    :param CodeableConcept region: Geographic area for the study
    :param str descriptionSummary: Brief text explaining the study
    :param str description: Detailed narrative of the study
    :param Period period: When the study began and ended
    :param Reference site: Facility where study activities are conducted
    :param Annotation note: Comments made about the study
    :param CodeableConcept classifier: Classification for the study
    :param AssociatedParty associatedParty: Sponsors, collaborators, and other parties
    :param ProgressStatus progressStatus: Status of study with time for that status
    :param CodeableConcept whyStopped: accrual-goal-met | closed-due-to-toxicity | closed-due-to-lack-of-study-progress | temporarily-closed-per-study-design
    :param Recruitment recruitment: Target or actual group of participants enrolled in study
    :param ComparisonGroup comparisonGroup: Defined path through the study for a subject
    :param Objective objective: A goal for the study
    :param OutcomeMeasure outcomeMeasure: A variable measured during the study
    :param Reference result: Link to results generated during the study
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "label": {"class_name": "Label", "is_contained": True},
        "protocol": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "primaryPurposeType": {"class_name": "CodeableConcept", "is_contained": False},
        "phase": {"class_name": "CodeableConcept", "is_contained": False},
        "studyDesign": {"class_name": "CodeableConcept", "is_contained": False},
        "focus": {"class_name": "CodeableReference", "is_contained": False},
        "condition": {"class_name": "CodeableConcept", "is_contained": False},
        "keyword": {"class_name": "CodeableConcept", "is_contained": False},
        "region": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "site": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "associatedParty": {"class_name": "AssociatedParty", "is_contained": True},
        "progressStatus": {"class_name": "ProgressStatus", "is_contained": True},
        "whyStopped": {"class_name": "CodeableConcept", "is_contained": False},
        "recruitment": {"class_name": "Recruitment", "is_contained": True},
        "comparisonGroup": {"class_name": "ComparisonGroup", "is_contained": True},
        "objective": {"class_name": "Objective", "is_contained": True},
        "outcomeMeasure": {"class_name": "OutcomeMeasure", "is_contained": True},
        "result": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        label: list["Label"] = None,
        protocol: list["Reference"] = None,
        partOf: list["Reference"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        date: "str" = None,
        status: "str" = None,
        primaryPurposeType: "CodeableConcept" = None,
        phase: "CodeableConcept" = None,
        studyDesign: list["CodeableConcept"] = None,
        focus: list["CodeableReference"] = None,
        condition: list["CodeableConcept"] = None,
        keyword: list["CodeableConcept"] = None,
        region: list["CodeableConcept"] = None,
        descriptionSummary: "str" = None,
        description: "str" = None,
        period: "Period" = None,
        site: list["Reference"] = None,
        note: list["Annotation"] = None,
        classifier: list["CodeableConcept"] = None,
        associatedParty: list["AssociatedParty"] = None,
        progressStatus: list["ProgressStatus"] = None,
        whyStopped: "CodeableConcept" = None,
        recruitment: "Recruitment" = None,
        comparisonGroup: list["ComparisonGroup"] = None,
        objective: list["Objective"] = None,
        outcomeMeasure: list["OutcomeMeasure"] = None,
        result: list["Reference"] = None,
    ):

        self.resourceType = "ResearchStudy"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.label = label or []
        self.protocol = protocol or []
        self.partOf = partOf or []
        self.relatedArtifact = relatedArtifact or []
        self.date = date
        self.status = status
        self.primaryPurposeType = primaryPurposeType
        self.phase = phase
        self.studyDesign = studyDesign or []
        self.focus = focus or []
        self.condition = condition or []
        self.keyword = keyword or []
        self.region = region or []
        self.descriptionSummary = descriptionSummary
        self.description = description
        self.period = period
        self.site = site or []
        self.note = note or []
        self.classifier = classifier or []
        self.associatedParty = associatedParty or []
        self.progressStatus = progressStatus or []
        self.whyStopped = whyStopped
        self.recruitment = recruitment
        self.comparisonGroup = comparisonGroup or []
        self.objective = objective or []
        self.outcomeMeasure = outcomeMeasure or []
        self.result = result or []

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Subscription. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class FilterBy(FhirBaseModel):
    """The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str resourceType: Allowed Resource (reference to definition) for this Subscription filter
    :param str filterParameter: Filter label defined in SubscriptionTopic
    :param str comparator: eq | ne | gt | lt | ge | le | sa | eb | ap
    :param str modifier: missing | exact | contains | not | text | in | not-in | below | above | type | identifier | of-type | code-text | text-advanced | iterate
    :param str value: Literal value or resource path
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        resourceType: "str" = None,
        filterParameter: "str" = None,
        comparator: "str" = None,
        modifier: "str" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.resourceType = resourceType
        self.filterParameter = filterParameter
        self.comparator = comparator
        self.modifier = modifier
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "Subscription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Subscription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Parameter(FhirBaseModel):
    """Channel-dependent information to send as part of the notification (e.g., HTTP Headers).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name (key) of the parameter
    :param str value: Value of the parameter to use or pass through
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "Subscription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Subscription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Subscription(DomainResource):
    """The subscription resource describes a particular client's request to be notified about a SubscriptionTopic.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Additional identifiers (business identifier)
    :param str name: Human readable name for this subscription
    :param str status: requested | active | error | off | entered-in-error
    :param str topic: Reference to the subscription topic being subscribed to
    :param ContactPoint contact: Contact details for source (e.g. troubleshooting)
    :param str end: When to automatically delete the subscription
    :param Reference managingEntity: Entity responsible for Subscription changes
    :param str reason: Description of why this subscription was created
    :param FilterBy filterBy: Criteria for narrowing the subscription topic stream
    :param Coding channelType: Channel type for notifications
    :param str endpoint: Where the channel points to
    :param Parameter parameter: Channel type
    :param int heartbeatPeriod: Interval in seconds to send 'heartbeat' notification
    :param int timeout: Timeout in seconds to attempt notification delivery
    :param str contentType: MIME type to send, or omit for no payload
    :param str content: empty | id-only | full-resource
    :param int maxCount: Maximum number of events that can be combined in a single notification
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactPoint", "is_contained": False},
        "managingEntity": {"class_name": "Reference", "is_contained": False},
        "filterBy": {"class_name": "FilterBy", "is_contained": True},
        "channelType": {"class_name": "Coding", "is_contained": False},
        "parameter": {"class_name": "Parameter", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        name: "str" = None,
        status: "str" = None,
        topic: "str" = None,
        contact: list["ContactPoint"] = None,
        end: "str" = None,
        managingEntity: "Reference" = None,
        reason: "str" = None,
        filterBy: list["FilterBy"] = None,
        channelType: "Coding" = None,
        endpoint: "str" = None,
        parameter: list["Parameter"] = None,
        heartbeatPeriod: "int" = None,
        timeout: "int" = None,
        contentType: "str" = None,
        content: "str" = None,
        maxCount: "int" = None,
    ):

        self.resourceType = "Subscription"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.name = name
        self.status = status
        self.topic = topic
        self.contact = contact or []
        self.end = end
        self.managingEntity = managingEntity
        self.reason = reason
        self.filterBy = filterBy or []
        self.channelType = channelType
        self.endpoint = endpoint
        self.parameter = parameter or []
        self.heartbeatPeriod = heartbeatPeriod
        self.timeout = timeout
        self.contentType = contentType
        self.content = content
        self.maxCount = maxCount

    @classmethod
    def from_dict(cls, data: dict) -> "Subscription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Subscription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Media. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Media(DomainResource):
    """A photo, video, or audio recording acquired or used in healthcare. The actual content may be inline or provided by direct reference.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifier(s) for the image
    :param Reference basedOn: Procedure that caused this media to be created
    :param Reference partOf: Part of referenced event
    :param str status: preparation | in-progress | not-done | on-hold | stopped | completed | entered-in-error | unknown
    :param CodeableConcept type: Classification of media as image, video, or audio
    :param CodeableConcept modality: The type of acquisition equipment/process
    :param CodeableConcept view: Imaging view, e.g. Lateral or Antero-posterior
    :param Reference subject: Who/What this Media is a record of
    :param Reference encounter: Encounter associated with media
    :param str createdDateTime: When Media was collected
    :param Period createdPeriod: When Media was collected
    :param str issued: Date/Time this version was made available
    :param Reference operator: The person who generated the image
    :param CodeableConcept reasonCode: Why was event performed?
    :param CodeableConcept bodySite: Observed body part
    :param str deviceName: Name of the device/manufacturer
    :param Reference device: Observing Device
    :param int height: Height of the image in pixels (photo/video)
    :param int width: Width of the image in pixels (photo/video)
    :param int frames: Number of frames if > 1 (photo)
    :param float duration: Length in seconds (audio / video)
    :param Attachment content: Actual Media - reference or data
    :param Annotation note: Comments made about the media
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "modality": {"class_name": "CodeableConcept", "is_contained": False},
        "view": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "createdPeriod": {"class_name": "Period", "is_contained": False},
        "operator": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "content": {"class_name": "Attachment", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        modality: "CodeableConcept" = None,
        view: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        createdDateTime: "str" = None,
        createdPeriod: "Period" = None,
        issued: "str" = None,
        operator: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        bodySite: "CodeableConcept" = None,
        deviceName: "str" = None,
        device: "Reference" = None,
        height: "int" = None,
        width: "int" = None,
        frames: "int" = None,
        duration: "float" = None,
        content: "Attachment" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "Media"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.status = status
        self.type = type
        self.modality = modality
        self.view = view
        self.subject = subject
        self.encounter = encounter
        self.createdDateTime = createdDateTime
        self.createdPeriod = createdPeriod
        self.issued = issued
        self.operator = operator
        self.reasonCode = reasonCode or []
        self.bodySite = bodySite
        self.deviceName = deviceName
        self.device = device
        self.height = height
        self.width = width
        self.frames = frames
        self.duration = duration
        self.content = content
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Media":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Media":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Reference. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *


class Reference(FhirBaseModel):
    """Base StructureDefinition for Reference Type: A reference from one resource to another.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str reference: Literal reference, Relative, internal or absolute URL
    :param str type: Type the reference refers to (e.g. "Patient")
    :param Identifier identifier: Logical reference, when literal reference is not known
    :param str display: Text alternative for the resource
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        reference: "str" = None,
        type: "str" = None,
        identifier: "Identifier" = None,
        display: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.reference = reference
        self.type = type
        self.identifier = identifier
        self.display = display

    @classmethod
    def from_dict(cls, data: dict) -> "Reference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Reference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationAdministration. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.Timing import *


class Performer(FhirBaseModel):
    """The performer of the medication treatment.  For devices this is the device that performed the administration of the medication.  An IV Pump would be an example of a device that is performing the administration. Both the IV Pump and the practitioner that set the rate or bolus on the pump can be listed as performers.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performance
    :param CodeableReference actor: Who or what performed the medication administration
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "CodeableReference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dosage(FhirBaseModel):
    """Describes the medication dosage information details e.g. dose, rate, site, route, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str text: Free text dosage instructions e.g. SIG
    :param CodeableConcept site: Body site administered to
    :param CodeableConcept route: Path of substance into body
    :param CodeableConcept method: How drug was administered
    :param Quantity dose: Amount of medication per dose
    :param Ratio rateRatio: Dose quantity per unit of time
    :param Quantity rateQuantity: Dose quantity per unit of time
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "site": {"class_name": "CodeableConcept", "is_contained": False},
        "route": {"class_name": "CodeableConcept", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "dose": {"class_name": "Quantity", "is_contained": False},
        "rateRatio": {"class_name": "Ratio", "is_contained": False},
        "rateQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        text: "str" = None,
        site: "CodeableConcept" = None,
        route: "CodeableConcept" = None,
        method: "CodeableConcept" = None,
        dose: "Quantity" = None,
        rateRatio: "Ratio" = None,
        rateQuantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.text = text
        self.site = site
        self.route = route
        self.method = method
        self.dose = dose
        self.rateRatio = rateRatio
        self.rateQuantity = rateQuantity

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationAdministration(DomainResource):
    """Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion. Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. This event can also be used to record waste using a status of not-done and the appropriate statusReason.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier
    :param Reference basedOn: Plan this is fulfilled by this administration
    :param Reference partOf: Part of referenced event
    :param str status: in-progress | not-done | on-hold | completed | entered-in-error | stopped | unknown
    :param CodeableConcept statusReason: Reason administration not performed
    :param CodeableConcept category: Type of medication administration
    :param CodeableReference medication: What was administered
    :param Reference subject: Who received medication
    :param Reference encounter: Encounter administered as part of
    :param Reference supportingInformation: Additional information to support administration
    :param str occurenceDateTime: Specific date/time or interval of time during which the administration took place (or did not take place)
    :param Period occurencePeriod: Specific date/time or interval of time during which the administration took place (or did not take place)
    :param Timing occurenceTiming: Specific date/time or interval of time during which the administration took place (or did not take place)
    :param str recorded: When the MedicationAdministration was first captured in the subject's record
    :param bool isSubPotent: Full dose was not administered
    :param CodeableConcept subPotentReason: Reason full dose was not administered
    :param Performer performer: Who or what performed the medication administration and what type of performance they did
    :param CodeableReference reason: Concept, condition or observation that supports why the medication was administered
    :param Reference request: Request administration performed against
    :param CodeableReference device: Device used to administer
    :param Annotation note: Information about the administration
    :param Dosage dosage: Details of how medication was taken
    :param Reference eventHistory: A list of events of interest in the lifecycle
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medication": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
        "occurencePeriod": {"class_name": "Period", "is_contained": False},
        "occurenceTiming": {"class_name": "Timing", "is_contained": False},
        "subPotentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": True},
        "eventHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReason: list["CodeableConcept"] = None,
        category: list["CodeableConcept"] = None,
        medication: "CodeableReference" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        supportingInformation: list["Reference"] = None,
        occurenceDateTime: "str" = None,
        occurencePeriod: "Period" = None,
        occurenceTiming: "Timing" = None,
        recorded: "str" = None,
        isSubPotent: "bool" = None,
        subPotentReason: list["CodeableConcept"] = None,
        performer: list["Performer"] = None,
        reason: list["CodeableReference"] = None,
        request: "Reference" = None,
        device: list["CodeableReference"] = None,
        note: list["Annotation"] = None,
        dosage: "Dosage" = None,
        eventHistory: list["Reference"] = None,
    ):

        self.resourceType = "MedicationAdministration"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.status = status
        self.statusReason = statusReason or []
        self.category = category or []
        self.medication = medication
        self.subject = subject
        self.encounter = encounter
        self.supportingInformation = supportingInformation or []
        self.occurenceDateTime = occurenceDateTime
        self.occurencePeriod = occurencePeriod
        self.occurenceTiming = occurenceTiming
        self.recorded = recorded
        self.isSubPotent = isSubPotent
        self.subPotentReason = subPotentReason or []
        self.performer = performer or []
        self.reason = reason or []
        self.request = request
        self.device = device or []
        self.note = note or []
        self.dosage = dosage
        self.eventHistory = eventHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Slot. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Slot(DomainResource):
    """A slot of time on a schedule that may be available for booking appointments.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this item
    :param CodeableConcept serviceCategory: A broad categorization of the service that is to be performed during this appointment
    :param CodeableReference serviceType: The type of appointments that can be booked into this slot (ideally this would be an identifiable service - which is at a location, rather than the location itself). If provided then this overrides the value provided on the Schedule resource
    :param CodeableConcept specialty: The specialty of a practitioner that would be required to perform the service requested in this appointment
    :param CodeableConcept appointmentType: The style of appointment or patient that may be booked in the slot (not service type)
    :param Reference schedule: The schedule resource that this slot defines an interval of status information
    :param str status: busy | free | busy-unavailable | busy-tentative | entered-in-error
    :param str start: Date/Time that the slot is to begin
    :param str end: Date/Time that the slot is to conclude
    :param bool overbooked: This slot has already been overbooked, appointments are unlikely to be accepted for this time
    :param str comment: Comments on the slot to describe any extended information. Such as custom constraints on the slot
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "serviceCategory": {"class_name": "CodeableConcept", "is_contained": False},
        "serviceType": {"class_name": "CodeableReference", "is_contained": False},
        "specialty": {"class_name": "CodeableConcept", "is_contained": False},
        "appointmentType": {"class_name": "CodeableConcept", "is_contained": False},
        "schedule": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        serviceCategory: list["CodeableConcept"] = None,
        serviceType: list["CodeableReference"] = None,
        specialty: list["CodeableConcept"] = None,
        appointmentType: list["CodeableConcept"] = None,
        schedule: "Reference" = None,
        status: "str" = None,
        start: "str" = None,
        end: "str" = None,
        overbooked: "bool" = None,
        comment: "str" = None,
    ):

        self.resourceType = "Slot"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.serviceCategory = serviceCategory or []
        self.serviceType = serviceType or []
        self.specialty = specialty or []
        self.appointmentType = appointmentType or []
        self.schedule = schedule
        self.status = status
        self.start = start
        self.end = end
        self.overbooked = overbooked
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "Slot":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Slot":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DeviceUseStatement. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *


class DeviceUseStatement(DomainResource):
    """A record of a device being used by a patient where the record is the result of a report from the patient or another clinician.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier for this record
    :param Reference basedOn: Fulfills plan, proposal or order
    :param str status: active | completed | entered-in-error +
    :param Reference subject: Patient using device
    :param Reference derivedFrom: Supporting information
    :param Timing timingTiming: How often  the device was used
    :param Period timingPeriod: How often  the device was used
    :param str timingDateTime: How often  the device was used
    :param str recordedOn: When statement was recorded
    :param Reference source: Who made the statement
    :param Reference device: Reference to device used
    :param CodeableConcept reasonCode: Why device was used
    :param Reference reasonReference: Why was DeviceUseStatement performed?
    :param CodeableConcept bodySite: Target body site
    :param Annotation note: Addition details (comments, instructions)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "timingTiming": {"class_name": "Timing", "is_contained": False},
        "timingPeriod": {"class_name": "Period", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        status: "str" = None,
        subject: "Reference" = None,
        derivedFrom: list["Reference"] = None,
        timingTiming: "Timing" = None,
        timingPeriod: "Period" = None,
        timingDateTime: "str" = None,
        recordedOn: "str" = None,
        source: "Reference" = None,
        device: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        bodySite: "CodeableConcept" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "DeviceUseStatement"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.status = status
        self.subject = subject
        self.derivedFrom = derivedFrom or []
        self.timingTiming = timingTiming
        self.timingPeriod = timingPeriod
        self.timingDateTime = timingDateTime
        self.recordedOn = recordedOn
        self.source = source
        self.device = device
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.bodySite = bodySite
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceUseStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceUseStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ClinicalImpression. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Finding(FhirBaseModel):
    """Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference item: What was found
    :param str basis: Which investigations support finding
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        item: "CodeableReference" = None,
        basis: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.item = item
        self.basis = basis

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalImpression":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalImpression":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ClinicalImpression(DomainResource):
    """A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier
    :param str status: preparation | in-progress | not-done | on-hold | stopped | completed | entered-in-error | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param str description: Why/how the assessment was performed
    :param Reference subject: Patient or group assessed
    :param Reference encounter: The Encounter during which this ClinicalImpression was created
    :param str effectiveDateTime: Time of assessment
    :param Period effectivePeriod: Time of assessment
    :param str date: When the assessment was documented
    :param Reference performer: The clinician performing the assessment
    :param Reference previous: Reference to last assessment
    :param Reference problem: Relevant impressions of patient state
    :param CodeableConcept changePattern: Change in the status/pattern of a subject's condition since previously assessed, such as worsening, improving, or no change
    :param str protocol: Clinical Protocol followed
    :param str summary: Summary of the assessment
    :param Finding finding: Possible or likely findings and diagnoses
    :param CodeableConcept prognosisCodeableConcept: Estimate of likely outcome
    :param Reference prognosisReference: RiskAssessment expressing likely outcome
    :param Reference supportingInfo: Information supporting the clinical impression
    :param Annotation note: Comments made about the ClinicalImpression
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "previous": {"class_name": "Reference", "is_contained": False},
        "problem": {"class_name": "Reference", "is_contained": False},
        "changePattern": {"class_name": "CodeableConcept", "is_contained": False},
        "finding": {"class_name": "Finding", "is_contained": True},
        "prognosisCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "prognosisReference": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        description: "str" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        effectiveDateTime: "str" = None,
        effectivePeriod: "Period" = None,
        date: "str" = None,
        performer: "Reference" = None,
        previous: "Reference" = None,
        problem: list["Reference"] = None,
        changePattern: "CodeableConcept" = None,
        protocol: list["str"] = None,
        summary: "str" = None,
        finding: list["Finding"] = None,
        prognosisCodeableConcept: list["CodeableConcept"] = None,
        prognosisReference: list["Reference"] = None,
        supportingInfo: list["Reference"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "ClinicalImpression"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.statusReason = statusReason
        self.description = description
        self.subject = subject
        self.encounter = encounter
        self.effectiveDateTime = effectiveDateTime
        self.effectivePeriod = effectivePeriod
        self.date = date
        self.performer = performer
        self.previous = previous
        self.problem = problem or []
        self.changePattern = changePattern
        self.protocol = protocol or []
        self.summary = summary
        self.finding = finding or []
        self.prognosisCodeableConcept = prognosisCodeableConcept or []
        self.prognosisReference = prognosisReference or []
        self.supportingInfo = supportingInfo or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalImpression":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalImpression":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Substance. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Instance(FhirBaseModel):
    """Substance may be used to describe a kind of substance, or a specific package/container of the substance: an instance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Identifier of the package/container
    :param str expiry: When no longer valid to use
    :param Quantity quantity: Amount of substance in the package
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        expiry: "str" = None,
        quantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.expiry = expiry
        self.quantity = quantity

    @classmethod
    def from_dict(cls, data: dict) -> "Substance":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Substance":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Ingredient(FhirBaseModel):
    """A substance can be composed of other substances.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Ratio quantity: Optional amount (concentration)
    :param CodeableConcept substanceCodeableConcept: A component of the substance
    :param Reference substanceReference: A component of the substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Ratio", "is_contained": False},
        "substanceCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "substanceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Ratio" = None,
        substanceCodeableConcept: "CodeableConcept" = None,
        substanceReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.substanceCodeableConcept = substanceCodeableConcept
        self.substanceReference = substanceReference

    @classmethod
    def from_dict(cls, data: dict) -> "Substance":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Substance":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substance(DomainResource):
    """A homogeneous material with a definite composition.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier
    :param str status: active | inactive | entered-in-error
    :param CodeableConcept category: What class/type of substance this is
    :param CodeableConcept code: What substance this is
    :param str description: Textual description of the substance, comments
    :param Instance instance: If this describes a specific package/container of the substance
    :param Ingredient ingredient: Composition information about the substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "instance": {"class_name": "Instance", "is_contained": True},
        "ingredient": {"class_name": "Ingredient", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        instance: list["Instance"] = None,
        ingredient: list["Ingredient"] = None,
    ):

        self.resourceType = "Substance"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.category = category or []
        self.code = code
        self.description = description
        self.instance = instance or []
        self.ingredient = ingredient or []

    @classmethod
    def from_dict(cls, data: dict) -> "Substance":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Substance":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for TriggerDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.DataRequirement import *
from fhirmodels.R4B.Expression import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Timing import *


class TriggerDefinition(FhirBaseModel):
    """Base StructureDefinition for TriggerDefinition Type: A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str type: named-event | periodic | data-changed | data-added | data-modified | data-removed | data-accessed | data-access-ended
    :param str name: Name or URI that identifies the event
    :param Timing timingTiming: Timing of the event
    :param Reference timingReference: Timing of the event
    :param str timingDate: Timing of the event
    :param str timingDateTime: Timing of the event
    :param DataRequirement data: Triggering data of the event (multiple = 'and')
    :param Expression condition: Whether the event triggers (boolean expression)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "timingTiming": {"class_name": "Timing", "is_contained": False},
        "timingReference": {"class_name": "Reference", "is_contained": False},
        "data": {"class_name": "DataRequirement", "is_contained": False},
        "condition": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "str" = None,
        name: "str" = None,
        timingTiming: "Timing" = None,
        timingReference: "Reference" = None,
        timingDate: "str" = None,
        timingDateTime: "str" = None,
        data: list["DataRequirement"] = None,
        condition: "Expression" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.type = type
        self.name = name
        self.timingTiming = timingTiming
        self.timingReference = timingReference
        self.timingDate = timingDate
        self.timingDateTime = timingDateTime
        self.data = data or []
        self.condition = condition

    @classmethod
    def from_dict(cls, data: dict) -> "TriggerDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TriggerDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
